import styles from './Home.less';
import React, { Fragment } from 'react';
import ReactDOM from 'react-dom';
import syntheticTrue from '../assets/syntheticTrue.png';
import syntheticFalse from '../assets/syntheticFalse.png';
import arrow from '../assets/arrow.png';
import banner from '../assets/banner.png';
import Resultmodal from './Resultmodal/Resultmodal.jsx';
import Activity from '@/components/Activity';
import Result from '@/components/Result/Result';
import NativeHook from '../utils/NativeHook';
import Photo from './Presentphoto';
import { Toast, PullToRefresh, ActivityIndicator } from 'antd-mobile';

const $ = window.$

export default class Home extends React.Component {
  constructor(props) {
    super(props);
    document.title = '碎片合成';
    NativeHook.init()
    this.state = {
      visible: false,
      listData: [],
      isActivity: false,
      signNum: null,
      imgUrl: null,
      informationObj: {},
      height: document.documentElement.clientHeight,
      isSynthetic: false
    }
  }

  //合成碎片
  onShow = (id, signNum, num, imgId, debris) => {
    this.setState({ isSynthetic: true })
    NativeHook.call.postData({
      api: '/api-app/v1/props/useProps',
      params: { bagId: id },
      isDialogShow: false
    }, (res) => {
      if (res.success && res.code === 'OK') {
        this.getPhoto(id, signNum, num, imgId, debris);
        this.setState({ isSynthetic: false })
      } else {
        this.setState({ isSynthetic: false })
        Toast.fail(res.msg, 1);
      }
    })
  }

  //礼物全图请求接口
  getPhoto = (id, signNum, num, imgId, debris) => {
    NativeHook.call.getData({
      api: `/api-app/v1/gift/getGift`,
      params: { giftId: imgId },
      isDialogShow: false
    }, (res) => {
      if (res.success && res.code === 'OK') {
        this.state.listData[signNum].quantity = this.state.listData[signNum].quantity - num;
        this.setState({
          isActivity: false,
          listData: this.state.listData,
          imgUrl: res.data.giftIcon || null,
          informationObj: {
            name: res.data.giftName,
            debris: debris
          }
        }, () => {
          this.setState({ visible: true })
        })
      } else {
        Toast.fail(res.msg, 1);
      }
    })
  }

  onClose = () => {
    this.setState({ visible: false })
  }

  componentDidMount() {
    //获取背包道具列表
    this.getPropsList()
    const hei = this.state.height - ReactDOM.findDOMNode(this.ptr).offsetTop;
    setTimeout(() => this.setState({
      height: hei
    }), 0);
  }

  componentWillUnmount() {
    if (NativeHook && NativeHook.destroy) {
      NativeHook.destroy()
    }
  }

  //上拉刷新
  onRefresh = () => {
    this.getPropsList();
  }

  //获取背包道具列表
  getPropsList = () => {
    this.setState({ isActivity: true })
    NativeHook.call.getData({
      api: '/api-app/v1/bag/getPropsList',
      params: { propsType: 107 },
      isDialogShow: false
    }, (res) => {
      if (res.success && res.code === 'OK') {
        this.setState({
          isActivity: false,
          listData: res.data.list || []
        })
      } else {
        this.setState({ isActivity: false })
        Toast.fail(res.msg, 1);
      }
    })
  }

  render() {
    const { visible, listData, isActivity, imgUrl, informationObj, isSynthetic } = this.state;

    return (
      <Fragment>
        <div
          style={listData.length > 2 ? null : { height: '100vh' }}
          className={styles.home}
        >
          <div style={isActivity ? { filter: 'blur(10px)' } : null}>
            <PullToRefresh
              onRefresh={this.onRefresh}
              ref={el => this.ptr = el}
              style={{
                color: '#fff',
                height: this.state.height,
                overflow: 'auto',
              }}
            >
              <img className={styles.bannerImg} src={banner} alt='error' />
              <div className={styles.mainContent}>
                {
                  listData.length === 0 ? <Result /> :
                    listData.map((item, index) => {
                      return (
                        <div key={index} className={styles.contentWrap}>
                          <div className={styles.childWrap}>
                            <div className={styles.childOne}>
                              <div className={styles.oneTop}>
                                <img src={item.item.propsIcon} alt='king' />
                                <div className={styles.numBer}>{item.quantity}</div>
                              </div>
                              <div>{item.item.propsName}</div>
                            </div>
                            <div className={styles.childTwo}>
                              <img src={arrow} alt="arrow" />
                              <div>{item.item.propsExtInt}碎片</div>
                            </div>
                            <Photo
                              imgId={item.item.propsExtString}
                              NativeHook={NativeHook}
                            />
                            <div
                              onClick={item.quantity < item.item.propsExtInt ?
                                () => Toast.fail('碎片不足', 1) :
                                () => this.onShow(
                                  item.bagId, index,
                                  item.item.propsExtInt,
                                  item.item.propsExtString,
                                  item.item.propsExtInt
                                )}
                              className={styles.childFour}
                            >
                              <img src={item.quantity < item.item.propsExtInt ? syntheticFalse : syntheticTrue} alt="error" />
                            </div>
                          </div>
                        </div>
                      )
                    })
                }
              </div>
            </PullToRefresh>
          </div>
          {
            visible ? <Resultmodal
              visible={visible}
              onClose={this.onClose}
              imgUrl={imgUrl}
              obj={informationObj}
              NativeHook={NativeHook}
            /> : null
          }
        </div>
        <Activity isActivity={isActivity} />
        <ActivityIndicator
          toast
          text={"正在合成"}
          animating={isSynthetic}
        />
      </Fragment>
    )
  }
}
